==> mastapy-14.0.0b1.tar.gz: mastapy-14.0.0b1/mastapy/_private/utility/units_and_measurements/measurements/_1720.py <==
"""LinearAngularStiffnessCrossTerm"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.utility.units_and_measurements import _1652
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_LINEAR_ANGULAR_STIFFNESS_CROSS_TERM = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements",
    "LinearAngularStiffnessCrossTerm",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="LinearAngularStiffnessCrossTerm")
    CastSelf = TypeVar(
        "CastSelf",
        bound="LinearAngularStiffnessCrossTerm._Cast_LinearAngularStiffnessCrossTerm",
    )


__docformat__ = "restructuredtext en"
__all__ = ("LinearAngularStiffnessCrossTerm",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LinearAngularStiffnessCrossTerm:
    """Special nested class for casting LinearAngularStiffnessCrossTerm to subclasses."""

    __parent__: "LinearAngularStiffnessCrossTerm"

    @property
    def measurement_base(self: "CastSelf") -> "_1652.MeasurementBase":
        return self.__parent__._cast(_1652.MeasurementBase)

    @property
    def linear_angular_stiffness_cross_term(
        self: "CastSelf",
    ) -> "LinearAngularStiffnessCrossTerm":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class LinearAngularStiffnessCrossTerm(_1652.MeasurementBase):
    """LinearAngularStiffnessCrossTerm

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LINEAR_ANGULAR_STIFFNESS_CROSS_TERM

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_LinearAngularStiffnessCrossTerm":
        """Cast to another type.

        Returns:
            _Cast_LinearAngularStiffnessCrossTerm
        """
        return _Cast_LinearAngularStiffnessCrossTerm(self)

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/utility/units_and_measurements/measurements/_1720.py <==
"""Integer"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1666

_INTEGER = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Integer"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Integer")
    CastSelf = TypeVar("CastSelf", bound="Integer._Cast_Integer")


__docformat__ = "restructuredtext en"
__all__ = ("Integer",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Integer:
    """Special nested class for casting Integer to subclasses."""

    __parent__: "Integer"

    @property
    def measurement_base(self: "CastSelf") -> "_1666.MeasurementBase":
        return self.__parent__._cast(_1666.MeasurementBase)

    @property
    def integer(self: "CastSelf") -> "Integer":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Integer(_1666.MeasurementBase):
    """Integer

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _INTEGER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Integer":
        """Cast to another type.

        Returns:
            _Cast_Integer
        """
        return _Cast_Integer(self)
